@@ -5,22 +5,36 @@ from .color_print import (
     colored,
     cprint,
     error,
-    hline,
+    line,
     info,
     italic,
     success,
     underline,
     warn,
+    red,
+    green,
+    blue,
+    cyan,
+    white,
+    black,
+    yellow,
 )
 from .utils import InvalidColorError
 
-__version__ = "0.0.6"
+__version__ = "0.0.7"
 __all__ = [
+    "red",
+    "green",
+    "blue",
+    "cyan",
+    "white",
+    "black",
+    "yellow",
     "bold",
     "colored",
     "cprint",
     "error",
-    "hline",
+    "line",
     "info",
     "italic",
     "success",
